package com.qmth.cqb.question.service;

import com.qmth.cqb.question.dao.ImportPaperRepo;
import com.qmth.cqb.question.model.ImportPaper;
import com.qmth.cqb.question.model.ImportPaperSearchCondition;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

/**
 * 导入试卷服务类
 * Created by songyue on 16/12/28.
 */
@Service
public class ImportPaperService {

    /**
     * 一般返回类型统一为NormalResponse对象
     * NormalResponse(String httpStatus, String Message)
     * 分页集合返回类型为PagingAndSortingResponse
     * PagingAndSortingResponse(int curPage, int pageSize, int totalPages, long totalElements, List dataList)
     * 一般集合返回类型为List
     */

    @Autowired
    ImportPaperRepo importPaperRepo;

    /**
     * 导入试卷
     * @param importPaper
     * @return
     */
    public NormalResponse importPaper(ImportPaper importPaper){
        ImportPaper tempPaper = importPaperRepo.save(importPaper);
        if(tempPaper != null){
            return new NormalResponse(HttpStatus.OK.toString(),"success");
        }else{
            return new NormalResponse(HttpStatus.INTERNAL_SERVER_ERROR.toString(),"导入失败");
        }
    }

    /**
     * 查询所有已导入试卷
     * @param searchCondition
     * @param curPage
     * @param pageSize
     * @return
     */
    public PagingAndSortingResponse<ImportPaper> findAll(ImportPaperSearchCondition searchCondition,int curPage,int pageSize){
    	ImportPaper importPaper = new ImportPaper();
    	BeanUtils.copyProperties(searchCondition,importPaper);
    	ExampleMatcher matcher = ExampleMatcher.matching().withMatcher("paperName", startsWith());
        Page<ImportPaper> importPaperList = importPaperRepo.findAll(Example.of(importPaper,matcher),new PageRequest(curPage-1,pageSize));
        return new PagingAndSortingResponse<ImportPaper>(importPaperList.getNumber(),importPaperList.getSize(),
                importPaperList.getTotalPages(),importPaperList.getTotalElements(),importPaperList.getContent());
    }

    /**
     * 按ID查询导入试卷
     * @param paperId
     * @return
     */
    public ImportPaper findById(String paperId){
        return importPaperRepo.findOne(paperId);
    }

    /**
     * 保存试卷
     * @param importPaper
     * @return
     */
    public ImportPaper saveImportPaper(ImportPaper importPaper){
        ImportPaper tempPaper = importPaperRepo.save(importPaper);
        return tempPaper;
//        if(tempPaper != null){
//            return new NormalResponse(HttpStatus.OK.toString(),"success");
//        }else{
//            return new NormalResponse(HttpStatus.INTERNAL_SERVER_ERROR.toString(),"保存失败");
//        }
    }

    /**
     * 删除导入试卷
     * @param paperId
     * @return
     */
    public NormalResponse deleteImportPaper(String paperId){
        importPaperRepo.delete(paperId);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }

}
