package com.qmth.cqb.question.service;

import com.qmth.cqb.question.dao.QuesRepo;
import com.qmth.cqb.question.model.QuestionType;
import com.qmth.cqb.question.model.Question;
import com.qmth.cqb.question.model.QuestionSearchCondition;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

/**
 * Created by songyue on 16/12/28.
 */
@Service
public class QuesService {

    /**
     * 一般返回类型统一为NormalResponse对象
     * NormalResponse(String httpStatus, String Message)
     * 分页集合返回类型为PagingAndSortingResponse
     * PagingAndSortingResponse(int curPage, int pageSize, int totalPages, long totalElements, List dataList)
     * 一般集合返回类型为List
     */

    @Autowired
    QuesRepo quesRepo;

    /**
     * 查询所有试题
     * @param searchCondition
     * @param curPage
     * @param pageSize
     * @return
     */
    public PagingAndSortingResponse<Question> findAll(QuestionSearchCondition searchCondition, int curPage, int pageSize){
    	Question que = new Question();
    	QuestionType qst = new QuestionType();
    	qst.setName(searchCondition.getQuesTypeName());
    	que.setQuesStructType(qst);
    	BeanUtils.copyProperties(searchCondition,que);
        Page<Question> quesList = quesRepo.findAll(Example.of(que),new PageRequest(curPage-1,pageSize));
        return new PagingAndSortingResponse<Question>(quesList.getNumber(),quesList.getSize(),
                quesList.getTotalPages(),quesList.getTotalElements(),quesList.getContent());
    }

    /**
     * 按ID查询试题
     * @param typeId
     * @return
     */
    public Question findById(String typeId){
        return quesRepo.findOne(typeId);
    }

    /**
     * 保存试题
     * @param question
     * @return
     */
    public Question saveQuestion(Question question){
        Question tempQues = quesRepo.save(question);
        return tempQues;
    }

    /**
     * 删除试题
     * @param typeId
     * @return
     */
    public void deleteQuestion(String typeId){
        quesRepo.delete(typeId);
    }
}
