package com.qmth.cqb.question.service;

import com.qmth.cqb.question.dao.QuestionTypeRepo;
import com.qmth.cqb.question.model.QuestionType;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

/**
 * 试题结构类型服务类
 * Created by songyue on 16/12/28.
 */
@Service
public class QuesStructTypeService {

    /**
     * 一般返回类型统一为NormalResponse对象
     * NormalResponse(String httpStatus, String Message)
     * 分页集合返回类型为PagingAndSortingResponse
     * PagingAndSortingResponse(int curPage, int pageSize, int totalPages, long totalElements, List dataList)
     * 一般集合返回类型为List
     */

    @Autowired
    QuestionTypeRepo quesStructTypeRepo;


    /**
     * 查询所有结构题型
     * @param searchCondition
     * @param curPage
     * @param pageSize
     * @return
     */
    public PagingAndSortingResponse<QuestionType> findAll(QuestionType searchCondition, int curPage, int pageSize){
        Page<QuestionType> quesStructTypeList = quesStructTypeRepo.findAll(Example.of(searchCondition),new PageRequest(curPage-1,pageSize));
        return new PagingAndSortingResponse<QuestionType>(quesStructTypeList.getNumber(),quesStructTypeList.getSize(),
                quesStructTypeList.getTotalPages(),quesStructTypeList.getTotalElements(),quesStructTypeList.getContent());
    }

    /**
     * 按ID查询结构题型
     * @param typeId
     * @return
     */
    public QuestionType findById(String typeId){
        return quesStructTypeRepo.findOne(typeId);
    }

    /**
     * 保存结构题型
     * @param quesStructType
     * @return
     */
    public NormalResponse saveQuesStructType(QuestionType quesStructType){
        QuestionType tempPaper = quesStructTypeRepo.save(quesStructType);
        if(tempPaper != null){
            return new NormalResponse(HttpStatus.OK.toString(),"success");
        }else{
            return new NormalResponse(HttpStatus.INTERNAL_SERVER_ERROR.toString(),"保存失败");
        }
    }

    /**
     * 删除结构题型
     * @param typeId
     * @return
     */
    public NormalResponse deleteQuesStructType(String typeId){
        quesStructTypeRepo.delete(typeId);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }


}
