package com.qmth.cqb.question.web;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.qmth.cqb.question.model.QuesOption;
import com.qmth.cqb.question.model.QuestionType;
import com.qmth.cqb.question.model.Question;
import com.qmth.cqb.question.model.QuestionSearchCondition;
import com.qmth.cqb.question.service.QuesService;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

import io.swagger.annotations.ApiOperation;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * Created by songyue on 16/12/28.
 */
@RestController
@RequestMapping("${api_cqb}/")
public class QuesController {
    @Autowired
    QuesService quesService;

      
    @Autowired
    Gson gson;


    /**
     * 获取试题
     * @param ques_id
     * @return
     */
    @ApiOperation(value="获取单个试题",notes="获取单个试题")
    @GetMapping(value = "/ques/{ques_id}")
    public Question getQuesById(@PathVariable String ques_id){
        return quesService.findById(ques_id);
    }

    /**
     * 获取全部试题
     * @return
     */
    @GetMapping(value = "/ques/all/{curPage}/{pageSize}")
    public PagingAndSortingResponse<Question> getAllQuestion(@ModelAttribute QuestionSearchCondition searchCondition, @PathVariable int curPage, @PathVariable int pageSize){
      PagingAndSortingResponse<Question> psr = quesService.findAll(searchCondition, curPage, pageSize);
      return psr;
    }

    /**
     * 更新试题信息
     * @param 
     * @return
     */
    @PutMapping(value = "/question")
    public ResponseEntity updateQuestion(@ModelAttribute Question ques){
    	//return quesService.saveQuestion(ques);
        Question qus = quesService.saveQuestion(ques);
        ResponseEntity rse = new ResponseEntity(qus,HttpStatus.OK);
        return rse;
    	
    }

    /**
     * 新增试题
     * @param question
     * @return
     */
    @PostMapping(value = "/question")
    public ResponseEntity addQuestion(@ModelAttribute Question ques){
//    	QuesOption opt1 =  new QuesOption();
//    	opt1.setOptionNo("1");
//    	opt1.setOptionBody("10");
//    	QuesOption opt2 =  new QuesOption();
//    	opt2.setOptionNo("2");
//    	opt2.setOptionBody("15");
//    	List<QuesOption> opts = new ArrayList<QuesOption>();
//    	opts.add(opt1);
//    	opts.add(opt2);
//    	QuesStructType type = new QuesStructType();
//    	type.setId("1");
//    	type.setTypeName("单选");
//    	type.setTypeTitle("单项选择题");
//    	Question questemp = new Question();
//    	questemp.setCreateTime("1");
//    	questemp.setQuesAnswer("B");
//    	questemp.setQuesBody("5乘以3等于几");
//    	questemp.setQuesOptions(opts);
//    	questemp.setQuesStructType(type);
//    	
//      String quesJson = gson.toJson(questemp);
//      Question ques = gson.fromJson(quesJson,Question.class);
      Question qus = quesService.saveQuestion(ques);
      ResponseEntity rse2 = new ResponseEntity(qus,HttpStatus.OK);
      return rse2;
    }

    /**
     * 删除试题
     * @param ques_id
     * @return
     */
    @DeleteMapping(value = "/ques/{ques_id}")
    public ResponseEntity removeQuestion(@PathVariable String ques_id){
    	quesService.deleteQuestion(ques_id);
    	ResponseEntity rse2 = new ResponseEntity(ques_id,HttpStatus.OK);
    	return rse2;
    }
}
